# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/foxtrot',
                'doc_host': 'https://licenseplated.github.io',
                'git_url': 'https://github.com/licenseplated/foxtrot',
                'lib_path': 'foxtrot'},
  'syms': {'foxtrot.core': {'foxtrot.core.say_hello': ('core.html#say_hello', 'foxtrot/core.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_core.ipynb.

# %% auto 0
__all__ = ['say_hello']

# %% ../nbs/00_core.ipynb 3
def say_hello(to):
    "Say hello to somebody"
    return f'Hello {to}!'
